
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "st-enum-types.h"
#include "st-adjustment.h"
#include "st-background-effect.h"
#include "st-bin.h"
#include "st-border-image.h"
#include "st-box-layout.h"
#include "st-box-layout-child.h"
#include "st-button.h"
#include "st-clipboard.h"
#include "st-drawing-area.h"
#include "st-entry.h"
#include "st-focus-manager.h"
#include "st-group.h"
#include "st-icon.h"
#include "st-icon-colors.h"
#include "st-label.h"
#include "st-image-content.h"
#include "st-password-entry.h"
#include "st-polygon.h"
#include "st-private.h"
#include "st-scrollable.h"
#include "st-scroll-bar.h"
#include "st-scroll-view.h"
#include "st-scroll-view-fade.h"
#include "st-settings.h"
#include "st-shadow.h"
#include "st-table.h"
#include "st-table-child.h"
#include "st-texture-cache.h"
#include "st-theme.h"
#include "st-theme-context.h"
#include "st-theme-node.h"
#include "st-types.h"
#include "st-viewport.h"
#include "st-widget.h"
#include "st-widget-accessible.h"

#define C_ENUM(v) ((gint) v)
#define C_FLAGS(v) ((guint) v)

/* enumerations from "st-button.h" */

GType
st_button_mask_get_type (void)
{
    static gsize gtype_id = 0;
    static const GFlagsValue values[] = {
        { C_FLAGS (ST_BUTTON_ONE), "ST_BUTTON_ONE", "one" },
        { C_FLAGS (ST_BUTTON_TWO), "ST_BUTTON_TWO", "two" },
        { C_FLAGS (ST_BUTTON_THREE), "ST_BUTTON_THREE", "three" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_flags_register_static (g_intern_static_string ("StButtonMask"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "st-clipboard.h" */

GType
st_clipboard_type_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (ST_CLIPBOARD_TYPE_PRIMARY), "ST_CLIPBOARD_TYPE_PRIMARY", "primary" },
        { C_ENUM (ST_CLIPBOARD_TYPE_CLIPBOARD), "ST_CLIPBOARD_TYPE_CLIPBOARD", "clipboard" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("StClipboardType"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "st-scroll-view.h" */

GType
st_policy_type_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (ST_POLICY_ALWAYS), "ST_POLICY_ALWAYS", "always" },
        { C_ENUM (ST_POLICY_AUTOMATIC), "ST_POLICY_AUTOMATIC", "automatic" },
        { C_ENUM (ST_POLICY_NEVER), "ST_POLICY_NEVER", "never" },
        { C_ENUM (ST_POLICY_EXTERNAL), "ST_POLICY_EXTERNAL", "external" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("StPolicyType"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "st-table.h" */

GType
st_table_child_options_get_type (void)
{
    static gsize gtype_id = 0;
    static const GFlagsValue values[] = {
        { C_FLAGS (ST_KEEP_ASPECT_RATIO), "ST_KEEP_ASPECT_RATIO", "keep-aspect-ratio" },
        { C_FLAGS (ST_X_EXPAND), "ST_X_EXPAND", "x-expand" },
        { C_FLAGS (ST_Y_EXPAND), "ST_Y_EXPAND", "y-expand" },
        { C_FLAGS (ST_X_FILL), "ST_X_FILL", "x-fill" },
        { C_FLAGS (ST_Y_FILL), "ST_Y_FILL", "y-fill" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_flags_register_static (g_intern_static_string ("StTableChildOptions"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "st-texture-cache.h" */

GType
st_texture_cache_policy_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (ST_TEXTURE_CACHE_POLICY_NONE), "ST_TEXTURE_CACHE_POLICY_NONE", "none" },
        { C_ENUM (ST_TEXTURE_CACHE_POLICY_FOREVER), "ST_TEXTURE_CACHE_POLICY_FOREVER", "forever" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("StTextureCachePolicy"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "st-theme-node.h" */

GType
st_side_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (ST_SIDE_TOP), "ST_SIDE_TOP", "top" },
        { C_ENUM (ST_SIDE_RIGHT), "ST_SIDE_RIGHT", "right" },
        { C_ENUM (ST_SIDE_BOTTOM), "ST_SIDE_BOTTOM", "bottom" },
        { C_ENUM (ST_SIDE_LEFT), "ST_SIDE_LEFT", "left" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("StSide"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
st_corner_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (ST_CORNER_TOPLEFT), "ST_CORNER_TOPLEFT", "topleft" },
        { C_ENUM (ST_CORNER_TOPRIGHT), "ST_CORNER_TOPRIGHT", "topright" },
        { C_ENUM (ST_CORNER_BOTTOMRIGHT), "ST_CORNER_BOTTOMRIGHT", "bottomright" },
        { C_ENUM (ST_CORNER_BOTTOMLEFT), "ST_CORNER_BOTTOMLEFT", "bottomleft" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("StCorner"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
st_text_decoration_get_type (void)
{
    static gsize gtype_id = 0;
    static const GFlagsValue values[] = {
        { C_FLAGS (ST_TEXT_DECORATION_UNDERLINE), "ST_TEXT_DECORATION_UNDERLINE", "underline" },
        { C_FLAGS (ST_TEXT_DECORATION_OVERLINE), "ST_TEXT_DECORATION_OVERLINE", "overline" },
        { C_FLAGS (ST_TEXT_DECORATION_LINE_THROUGH), "ST_TEXT_DECORATION_LINE_THROUGH", "line-through" },
        { C_FLAGS (ST_TEXT_DECORATION_BLINK), "ST_TEXT_DECORATION_BLINK", "blink" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_flags_register_static (g_intern_static_string ("StTextDecoration"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
st_text_align_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (ST_TEXT_ALIGN_LEFT), "ST_TEXT_ALIGN_LEFT", "left" },
        { C_ENUM (ST_TEXT_ALIGN_CENTER), "ST_TEXT_ALIGN_CENTER", "center" },
        { C_ENUM (ST_TEXT_ALIGN_RIGHT), "ST_TEXT_ALIGN_RIGHT", "right" },
        { C_ENUM (ST_TEXT_ALIGN_JUSTIFY), "ST_TEXT_ALIGN_JUSTIFY", "justify" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("StTextAlign"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
st_gradient_type_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (ST_GRADIENT_NONE), "ST_GRADIENT_NONE", "none" },
        { C_ENUM (ST_GRADIENT_VERTICAL), "ST_GRADIENT_VERTICAL", "vertical" },
        { C_ENUM (ST_GRADIENT_HORIZONTAL), "ST_GRADIENT_HORIZONTAL", "horizontal" },
        { C_ENUM (ST_GRADIENT_RADIAL), "ST_GRADIENT_RADIAL", "radial" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("StGradientType"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
st_icon_style_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (ST_ICON_STYLE_REQUESTED), "ST_ICON_STYLE_REQUESTED", "requested" },
        { C_ENUM (ST_ICON_STYLE_REGULAR), "ST_ICON_STYLE_REGULAR", "regular" },
        { C_ENUM (ST_ICON_STYLE_SYMBOLIC), "ST_ICON_STYLE_SYMBOLIC", "symbolic" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("StIconStyle"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "st-types.h" */

GType
st_align_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (ST_ALIGN_START), "ST_ALIGN_START", "start" },
        { C_ENUM (ST_ALIGN_MIDDLE), "ST_ALIGN_MIDDLE", "middle" },
        { C_ENUM (ST_ALIGN_END), "ST_ALIGN_END", "end" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("StAlign"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
st_icon_type_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (ST_ICON_SYMBOLIC), "ST_ICON_SYMBOLIC", "symbolic" },
        { C_ENUM (ST_ICON_FULLCOLOR), "ST_ICON_FULLCOLOR", "fullcolor" },
        { C_ENUM (ST_ICON_APPLICATION), "ST_ICON_APPLICATION", "application" },
        { C_ENUM (ST_ICON_DOCUMENT), "ST_ICON_DOCUMENT", "document" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("StIconType"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
st_background_size_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (ST_BACKGROUND_SIZE_AUTO), "ST_BACKGROUND_SIZE_AUTO", "auto" },
        { C_ENUM (ST_BACKGROUND_SIZE_CONTAIN), "ST_BACKGROUND_SIZE_CONTAIN", "contain" },
        { C_ENUM (ST_BACKGROUND_SIZE_COVER), "ST_BACKGROUND_SIZE_COVER", "cover" },
        { C_ENUM (ST_BACKGROUND_SIZE_FIXED), "ST_BACKGROUND_SIZE_FIXED", "fixed" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("StBackgroundSize"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "st-widget.h" */

GType
st_text_direction_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (ST_TEXT_DIRECTION_NONE), "ST_TEXT_DIRECTION_NONE", "none" },
        { C_ENUM (ST_TEXT_DIRECTION_LTR), "ST_TEXT_DIRECTION_LTR", "ltr" },
        { C_ENUM (ST_TEXT_DIRECTION_RTL), "ST_TEXT_DIRECTION_RTL", "rtl" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("StTextDirection"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* Generated data ends here */

