/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CINNAMON_CALENDAR_H__
#define __CINNAMON_CALENDAR_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.cinnamon.CalendarServer */

#define CINNAMON_TYPE_CALENDAR_SERVER (cinnamon_calendar_server_get_type ())
#define CINNAMON_CALENDAR_SERVER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CINNAMON_TYPE_CALENDAR_SERVER, CinnamonCalendarServer))
#define CINNAMON_IS_CALENDAR_SERVER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CINNAMON_TYPE_CALENDAR_SERVER))
#define CINNAMON_CALENDAR_SERVER_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CINNAMON_TYPE_CALENDAR_SERVER, CinnamonCalendarServerIface))

struct _CinnamonCalendarServer;
typedef struct _CinnamonCalendarServer CinnamonCalendarServer;
typedef struct _CinnamonCalendarServerIface CinnamonCalendarServerIface;

struct _CinnamonCalendarServerIface
{
  GTypeInterface parent_iface;



  gboolean (*handle_exit) (
    CinnamonCalendarServer *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_set_time_range) (
    CinnamonCalendarServer *object,
    GDBusMethodInvocation *invocation,
    gint64 arg_since,
    gint64 arg_until,
    gboolean arg_force_reload);

  gint64  (*get_since) (CinnamonCalendarServer *object);

  guint  (*get_status) (CinnamonCalendarServer *object);

  gint64  (*get_until) (CinnamonCalendarServer *object);

  void (*client_disappeared) (
    CinnamonCalendarServer *object,
    const gchar *arg_source_uid);

  void (*events_added_or_updated) (
    CinnamonCalendarServer *object,
    GVariant *arg_events);

  void (*events_removed) (
    CinnamonCalendarServer *object,
    const gchar *arg_ids);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CinnamonCalendarServer, g_object_unref)
#endif

GType cinnamon_calendar_server_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *cinnamon_calendar_server_interface_info (void);
guint cinnamon_calendar_server_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void cinnamon_calendar_server_complete_set_time_range (
    CinnamonCalendarServer *object,
    GDBusMethodInvocation *invocation);

void cinnamon_calendar_server_complete_exit (
    CinnamonCalendarServer *object,
    GDBusMethodInvocation *invocation);



/* D-Bus signal emissions functions: */
void cinnamon_calendar_server_emit_events_added_or_updated (
    CinnamonCalendarServer *object,
    GVariant *arg_events);

void cinnamon_calendar_server_emit_events_removed (
    CinnamonCalendarServer *object,
    const gchar *arg_ids);

void cinnamon_calendar_server_emit_client_disappeared (
    CinnamonCalendarServer *object,
    const gchar *arg_source_uid);



/* D-Bus method calls: */
void cinnamon_calendar_server_call_set_time_range (
    CinnamonCalendarServer *proxy,
    gint64 arg_since,
    gint64 arg_until,
    gboolean arg_force_reload,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cinnamon_calendar_server_call_set_time_range_finish (
    CinnamonCalendarServer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cinnamon_calendar_server_call_set_time_range_sync (
    CinnamonCalendarServer *proxy,
    gint64 arg_since,
    gint64 arg_until,
    gboolean arg_force_reload,
    GCancellable *cancellable,
    GError **error);

void cinnamon_calendar_server_call_exit (
    CinnamonCalendarServer *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cinnamon_calendar_server_call_exit_finish (
    CinnamonCalendarServer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cinnamon_calendar_server_call_exit_sync (
    CinnamonCalendarServer *proxy,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
gint64 cinnamon_calendar_server_get_since (CinnamonCalendarServer *object);
void cinnamon_calendar_server_set_since (CinnamonCalendarServer *object, gint64 value);

gint64 cinnamon_calendar_server_get_until (CinnamonCalendarServer *object);
void cinnamon_calendar_server_set_until (CinnamonCalendarServer *object, gint64 value);

guint cinnamon_calendar_server_get_status (CinnamonCalendarServer *object);
void cinnamon_calendar_server_set_status (CinnamonCalendarServer *object, guint value);


/* ---- */

#define CINNAMON_TYPE_CALENDAR_SERVER_PROXY (cinnamon_calendar_server_proxy_get_type ())
#define CINNAMON_CALENDAR_SERVER_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CINNAMON_TYPE_CALENDAR_SERVER_PROXY, CinnamonCalendarServerProxy))
#define CINNAMON_CALENDAR_SERVER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CINNAMON_TYPE_CALENDAR_SERVER_PROXY, CinnamonCalendarServerProxyClass))
#define CINNAMON_CALENDAR_SERVER_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CINNAMON_TYPE_CALENDAR_SERVER_PROXY, CinnamonCalendarServerProxyClass))
#define CINNAMON_IS_CALENDAR_SERVER_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CINNAMON_TYPE_CALENDAR_SERVER_PROXY))
#define CINNAMON_IS_CALENDAR_SERVER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CINNAMON_TYPE_CALENDAR_SERVER_PROXY))

typedef struct _CinnamonCalendarServerProxy CinnamonCalendarServerProxy;
typedef struct _CinnamonCalendarServerProxyClass CinnamonCalendarServerProxyClass;
typedef struct _CinnamonCalendarServerProxyPrivate CinnamonCalendarServerProxyPrivate;

struct _CinnamonCalendarServerProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  CinnamonCalendarServerProxyPrivate *priv;
};

struct _CinnamonCalendarServerProxyClass
{
  GDBusProxyClass parent_class;
};

GType cinnamon_calendar_server_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CinnamonCalendarServerProxy, g_object_unref)
#endif

void cinnamon_calendar_server_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CinnamonCalendarServer *cinnamon_calendar_server_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
CinnamonCalendarServer *cinnamon_calendar_server_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void cinnamon_calendar_server_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CinnamonCalendarServer *cinnamon_calendar_server_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
CinnamonCalendarServer *cinnamon_calendar_server_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CINNAMON_TYPE_CALENDAR_SERVER_SKELETON (cinnamon_calendar_server_skeleton_get_type ())
#define CINNAMON_CALENDAR_SERVER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CINNAMON_TYPE_CALENDAR_SERVER_SKELETON, CinnamonCalendarServerSkeleton))
#define CINNAMON_CALENDAR_SERVER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CINNAMON_TYPE_CALENDAR_SERVER_SKELETON, CinnamonCalendarServerSkeletonClass))
#define CINNAMON_CALENDAR_SERVER_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CINNAMON_TYPE_CALENDAR_SERVER_SKELETON, CinnamonCalendarServerSkeletonClass))
#define CINNAMON_IS_CALENDAR_SERVER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CINNAMON_TYPE_CALENDAR_SERVER_SKELETON))
#define CINNAMON_IS_CALENDAR_SERVER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CINNAMON_TYPE_CALENDAR_SERVER_SKELETON))

typedef struct _CinnamonCalendarServerSkeleton CinnamonCalendarServerSkeleton;
typedef struct _CinnamonCalendarServerSkeletonClass CinnamonCalendarServerSkeletonClass;
typedef struct _CinnamonCalendarServerSkeletonPrivate CinnamonCalendarServerSkeletonPrivate;

struct _CinnamonCalendarServerSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  CinnamonCalendarServerSkeletonPrivate *priv;
};

struct _CinnamonCalendarServerSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType cinnamon_calendar_server_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CinnamonCalendarServerSkeleton, g_object_unref)
#endif

CinnamonCalendarServer *cinnamon_calendar_server_skeleton_new (void);


G_END_DECLS

#endif /* __CINNAMON_CALENDAR_H__ */
