
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "cinnamon-enum-types.h"
#include "cinnamon-action-mode.h"
#include "cinnamon-app.h"
#include "cinnamon-app-system.h"
#include "cinnamon-doc-system.h"
#include "cinnamon-embedded-window.h"
#include "cinnamon-generic-container.h"
#include "cinnamon-glsl-effect.h"
#include "cinnamon-gtk-embed.h"
#include "cinnamon-global.h"
#include "cinnamon-perf-log.h"
#include "cinnamon-screen.h"
#include "cinnamon-screenshot.h"
#include "cinnamon-slicer.h"
#include "cinnamon-stack.h"
#include "cinnamon-touchegg-client.h"
#include "cinnamon-tray-icon.h"
#include "cinnamon-tray-manager.h"
#include "cinnamon-util.h"
#include "cinnamon-window-tracker.h"
#include "cinnamon-wm.h"

#define C_ENUM(v) ((gint) v)
#define C_FLAGS(v) ((guint) v)

/* enumerations from "cinnamon-action-mode.h" */

GType
cinnamon_action_mode_get_type (void)
{
    static gsize gtype_id = 0;
    static const GFlagsValue values[] = {
        { C_FLAGS (CINNAMON_ACTION_MODE_NONE), "CINNAMON_ACTION_MODE_NONE", "none" },
        { C_FLAGS (CINNAMON_ACTION_MODE_NORMAL), "CINNAMON_ACTION_MODE_NORMAL", "normal" },
        { C_FLAGS (CINNAMON_ACTION_MODE_OVERVIEW), "CINNAMON_ACTION_MODE_OVERVIEW", "overview" },
        { C_FLAGS (CINNAMON_ACTION_MODE_LOCK_SCREEN), "CINNAMON_ACTION_MODE_LOCK_SCREEN", "lock-screen" },
        { C_FLAGS (CINNAMON_ACTION_MODE_UNLOCK_SCREEN), "CINNAMON_ACTION_MODE_UNLOCK_SCREEN", "unlock-screen" },
        { C_FLAGS (CINNAMON_ACTION_MODE_LOGIN_SCREEN), "CINNAMON_ACTION_MODE_LOGIN_SCREEN", "login-screen" },
        { C_FLAGS (CINNAMON_ACTION_MODE_SYSTEM_MODAL), "CINNAMON_ACTION_MODE_SYSTEM_MODAL", "system-modal" },
        { C_FLAGS (CINNAMON_ACTION_MODE_LOOKING_GLASS), "CINNAMON_ACTION_MODE_LOOKING_GLASS", "looking-glass" },
        { C_FLAGS (CINNAMON_ACTION_MODE_POPUP), "CINNAMON_ACTION_MODE_POPUP", "popup" },
        { C_FLAGS (CINNAMON_ACTION_MODE_ALL), "CINNAMON_ACTION_MODE_ALL", "all" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_flags_register_static (g_intern_static_string ("CinnamonActionMode"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "cinnamon-app.h" */

GType
cinnamon_app_state_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (CINNAMON_APP_STATE_STOPPED), "CINNAMON_APP_STATE_STOPPED", "stopped" },
        { C_ENUM (CINNAMON_APP_STATE_STARTING), "CINNAMON_APP_STATE_STARTING", "starting" },
        { C_ENUM (CINNAMON_APP_STATE_RUNNING), "CINNAMON_APP_STATE_RUNNING", "running" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("CinnamonAppState"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "cinnamon-global.h" */

GType
cinnamon_stage_input_mode_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (CINNAMON_STAGE_INPUT_MODE_NONREACTIVE), "CINNAMON_STAGE_INPUT_MODE_NONREACTIVE", "nonreactive" },
        { C_ENUM (CINNAMON_STAGE_INPUT_MODE_NORMAL), "CINNAMON_STAGE_INPUT_MODE_NORMAL", "normal" },
        { C_ENUM (CINNAMON_STAGE_INPUT_MODE_FOCUSED), "CINNAMON_STAGE_INPUT_MODE_FOCUSED", "focused" },
        { C_ENUM (CINNAMON_STAGE_INPUT_MODE_FULLSCREEN), "CINNAMON_STAGE_INPUT_MODE_FULLSCREEN", "fullscreen" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("CinnamonStageInputMode"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
cinnamon_cursor_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (CINNAMON_CURSOR_DND_IN_DRAG), "CINNAMON_CURSOR_DND_IN_DRAG", "dnd-in-drag" },
        { C_ENUM (CINNAMON_CURSOR_DND_UNSUPPORTED_TARGET), "CINNAMON_CURSOR_DND_UNSUPPORTED_TARGET", "dnd-unsupported-target" },
        { C_ENUM (CINNAMON_CURSOR_DND_MOVE), "CINNAMON_CURSOR_DND_MOVE", "dnd-move" },
        { C_ENUM (CINNAMON_CURSOR_DND_COPY), "CINNAMON_CURSOR_DND_COPY", "dnd-copy" },
        { C_ENUM (CINNAMON_CURSOR_POINTING_HAND), "CINNAMON_CURSOR_POINTING_HAND", "pointing-hand" },
        { C_ENUM (CINNAMON_CURSOR_RESIZE_BOTTOM), "CINNAMON_CURSOR_RESIZE_BOTTOM", "resize-bottom" },
        { C_ENUM (CINNAMON_CURSOR_RESIZE_TOP), "CINNAMON_CURSOR_RESIZE_TOP", "resize-top" },
        { C_ENUM (CINNAMON_CURSOR_RESIZE_LEFT), "CINNAMON_CURSOR_RESIZE_LEFT", "resize-left" },
        { C_ENUM (CINNAMON_CURSOR_RESIZE_RIGHT), "CINNAMON_CURSOR_RESIZE_RIGHT", "resize-right" },
        { C_ENUM (CINNAMON_CURSOR_RESIZE_BOTTOM_RIGHT), "CINNAMON_CURSOR_RESIZE_BOTTOM_RIGHT", "resize-bottom-right" },
        { C_ENUM (CINNAMON_CURSOR_RESIZE_BOTTOM_LEFT), "CINNAMON_CURSOR_RESIZE_BOTTOM_LEFT", "resize-bottom-left" },
        { C_ENUM (CINNAMON_CURSOR_RESIZE_TOP_RIGHT), "CINNAMON_CURSOR_RESIZE_TOP_RIGHT", "resize-top-right" },
        { C_ENUM (CINNAMON_CURSOR_RESIZE_TOP_LEFT), "CINNAMON_CURSOR_RESIZE_TOP_LEFT", "resize-top-left" },
        { C_ENUM (CINNAMON_CURSOR_CROSSHAIR), "CINNAMON_CURSOR_CROSSHAIR", "crosshair" },
        { C_ENUM (CINNAMON_CURSOR_TEXT), "CINNAMON_CURSOR_TEXT", "text" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("CinnamonCursor"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "cinnamon-glsl-effect.h" */

GType
cinnamon_snippet_hook_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (CINNAMON_SNIPPET_HOOK_VERTEX), "CINNAMON_SNIPPET_HOOK_VERTEX", "vertex" },
        { C_ENUM (CINNAMON_SNIPPET_HOOK_VERTEX_TRANSFORM), "CINNAMON_SNIPPET_HOOK_VERTEX_TRANSFORM", "vertex-transform" },
        { C_ENUM (CINNAMON_SNIPPET_HOOK_FRAGMENT), "CINNAMON_SNIPPET_HOOK_FRAGMENT", "fragment" },
        { C_ENUM (CINNAMON_SNIPPET_HOOK_TEXTURE_COORD_TRANSFORM), "CINNAMON_SNIPPET_HOOK_TEXTURE_COORD_TRANSFORM", "texture-coord-transform" },
        { C_ENUM (CINNAMON_SNIPPET_HOOK_LAYER_FRAGMENT), "CINNAMON_SNIPPET_HOOK_LAYER_FRAGMENT", "layer-fragment" },
        { C_ENUM (CINNAMON_SNIPPET_HOOK_TEXTURE_LOOKUP), "CINNAMON_SNIPPET_HOOK_TEXTURE_LOOKUP", "texture-lookup" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("CinnamonSnippetHook"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* Generated data ends here */

