
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "cinnamon-action-mode.h" */

GType cinnamon_action_mode_get_type (void);
#define CINNAMON_TYPE_ACTION_MODE (cinnamon_action_mode_get_type())

/* enumerations from "cinnamon-app.h" */

GType cinnamon_app_state_get_type (void);
#define CINNAMON_TYPE_APP_STATE (cinnamon_app_state_get_type())

/* enumerations from "cinnamon-global.h" */

GType cinnamon_stage_input_mode_get_type (void);
#define CINNAMON_TYPE_STAGE_INPUT_MODE (cinnamon_stage_input_mode_get_type())

GType cinnamon_cursor_get_type (void);
#define CINNAMON_TYPE_CURSOR (cinnamon_cursor_get_type())

/* enumerations from "cinnamon-glsl-effect.h" */

GType cinnamon_snippet_hook_get_type (void);
#define CINNAMON_TYPE_SNIPPET_HOOK (cinnamon_snippet_hook_get_type())

G_END_DECLS

/* Generated data ends here */

